@@ -24,7 +24,7 @@ log = logging.getLogger(__name__)
 
 @attr.s(kw_only=True, slots=True, hash=True)
 class EventListener:
-    timeout = attr.ib(default=60)
+    timeout = attr.ib(default=240)
     address = attr.ib(init=False)
     store = attr.ib(init=False, repr=False, hash=False)
     sentinel = attr.ib(init=False, repr=False, hash=False)
@@ -71,7 +71,9 @@ class EventListener:
                     to_remove.append((received, expire, master_id, tag, data))
 
             for entry in to_remove:
+                log.debug("Removing from event store: %s", entry)
                 self.store.remove(entry)
+            log.debug("Event store size: %s", len(self.store))
 
     def start(self):
         if self.running_event.is_set():
@@ -121,6 +123,12 @@ class EventListener:
         return True
 
     def get_events(self, patterns, after_time=None):
+        log.debug(
+            "%s is checking for event patterns happening after %s: %s",
+            self,
+            after_time,
+            set(patterns),
+        )
         found_patterns = set()
         patterns = set(patterns)
         if after_time is None:
@@ -136,6 +144,17 @@ class EventListener:
                 if fnmatch.fnmatch(tag, _pattern):
                     log.debug("Found matching pattern: %s", pattern)
                     found_patterns.add(pattern)
+        if found_patterns:
+            log.debug(
+                "%s found the following patterns happening after %s: %s",
+                self,
+                after_time,
+                found_patterns,
+            )
+        else:
+            log.debug(
+                "%s did not find any matching event patterns happening after %s", self, after_time
+            )
         return found_patterns
 
     def register_auth_event_handler(self, master_id, callback):
